﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Infragistics.Win.Misc;
using Infragistics.Win;
using System.Drawing;

namespace WTP_CustomButton
{
    class CustomCreationFilter : IUIElementCreationFilter
    {
        private int buttonWidth = 70;
        public event EventHandler<UIElementEventArgs> ButtonClicked;
        private Appearance hotTrackButtonAppearance;

        public CustomCreationFilter(Appearance hotTrackButtonAppearance)
        {
            this.hotTrackButtonAppearance = hotTrackButtonAppearance;
        }

        public void AfterCreateChildElements(UIElement parent)
        {
            var tileHeaderEl = parent as TileHeaderUIElement;

            if (tileHeaderEl == null)
                return;


            var buttonUIElement = tileHeaderEl.GetDescendant(typeof(MyButtonUIElement)) as MyButtonUIElement;
            if (buttonUIElement == null)
            {
                buttonUIElement = new MyButtonUIElement(tileHeaderEl, hotTrackButtonAppearance);
                tileHeaderEl.ChildElements.Add(buttonUIElement);
            }

            var firstHeaderButtons = tileHeaderEl.ChildElements.OfType<TileHeaderButtonUIElement>().ToList();

            if (firstHeaderButtons.Count > 0)
            {
                var firstHeaderButton = firstHeaderButtons.OrderBy(b => b.Rect.X).First();
                buttonUIElement.Rect = new Rectangle(firstHeaderButton.Rect.X - buttonWidth - 1,
                    firstHeaderButton.Rect.Y, buttonWidth, firstHeaderButton.Rect.Height);
            }
            else
            {
                buttonUIElement.Rect = new Rectangle(parent.Rect.Right - buttonWidth - 1,
                    tileHeaderEl.Rect.Y, buttonWidth, tileHeaderEl.Rect.Height);
            }

            buttonUIElement.Text = "Click me!";

            buttonUIElement.ElementClick += buttonUIElement_ElementClick;
        }

        void buttonUIElement_ElementClick(object sender, UIElementEventArgs e)
        {
            if (ButtonClicked != null)
                ButtonClicked.Invoke(sender, e);
        }



        public bool BeforeCreateChildElements(UIElement parent)
        {
            return false;
        }
    }
}